@@ -31,11 +31,11 @@ def test_unset(flags):
 
 
 def test_repr(flags):
-    assert repr(flags) == "<wtforms.fields.Flags: {required}>"
+    assert repr(flags) == "<wtforms.fields.Flags: {required=True}>"
 
 
 def test_underscore_property(flags):
     with pytest.raises(AttributeError):
-        flags._foo
+        flags._foo  # noqa: B018
     flags._foo = 42
     assert flags._foo == 42
